Package: Zelig
License: GPL (>= 3)
Title: Everyone's Statistical Software
Authors@R: c(
    person("Christine", "Choirat", role = "aut"),
    person("Christopher", "Gandrud", role = "aut"),
    person("James", "Honaker", role = "aut"),
    person("Kosuke", "Imai", role = "aut"),
    person("Gary", "King", role = "aut"),
    person("Olivia", "Lau", role = "aut"),
    person("Robert", "Treacy", email = "zelig.zee@gmail.com", role = c("aut", "cre")),
    person("IQSS", "Harvard University", role = "cph")
    )
Description: A framework that brings together an abundance of common
    statistical models found across packages into a unified interface, and
    provides a common architecture for estimation and interpretation, as well
    as bridging functions to absorb increasingly more models into the
    package. Zelig allows each individual package, for each
    statistical model, to be accessed by a common uniformly structured call and
    set of arguments. Moreover, Zelig automates all the surrounding building
    blocks of a statistical work-flow--procedures and algorithms that may be
    essential to one user's application but which the original package
    developer did not use in their own research and might not themselves
    support. These include bootstrapping, jackknifing, and re-weighting of data.
    In particular, Zelig automatically generates predicted and simulated
    quantities of interest (such as relative risk ratios, average treatment
    effects, first differences and predicted and expected values) to interpret
    and visualize complex models.
URL: https://cran.r-project.org/package=Zelig
BugReports: https://github.com/IQSS/Zelig/issues
Version: 5.1.7
Date: 2020-12-03
Depends: survival
Imports: AER, Amelia, coda, dplyr (>= 0.3.0.2), Formula, geepack,
        jsonlite, sandwich, MASS, MatchIt, maxLik, MCMCpack, methods,
        quantreg, survey, VGAM
Suggests: ei, eiPack, knitr, networkD3, optmatch, rmarkdown, testthat
Collate: 'assertions.R' 'model-zelig.R' 'model-timeseries.R'
        'model-ma.R' 'model-ar.R' 'model-arima.R' 'model-weibull.R'
        'model-tobit.R' 'model-bayes.R' 'model-tobit-bayes.R'
        'model-glm.R' 'model-binchoice.R' 'model-probit.R'
        'model-probit-bayes.R' 'model-poisson.R'
        'model-poisson-bayes.R' 'model-oprobit-bayes.R'
        'model-normal.R' 'model-normal-bayes.R' 'model-mlogit-bayes.R'
        'model-gamma.R' 'model-gee.R' 'model-logit.R'
        'model-logit-bayes.R' 'model-factor-bayes.R'
        'model-poisson-gee.R' 'model-normal-gee.R' 'model-gamma-gee.R'
        'model-binchoice-gee.R' 'model-probit-gee.R'
        'model-logit-gee.R' 'model-relogit.R' 'model-quantile.R'
        'model-lognorm.R' 'model-exp.R' 'model-negbinom.R'
        'model-ivreg.R' 'model-ls.R' 'utils.R' 'create-json.R'
        'datasets.R' 'interface.R' 'model-survey.R'
        'model-binchoice-survey.R' 'model-gamma-survey.R'
        'model-logit-survey.R' 'model-normal-survey.R'
        'model-poisson-survey.R' 'model-probit-survey.R' 'plots.R'
        'wrappers.R'
RoxygenNote: 7.1.1
NeedsCompilation: no
Packaged: 2020-12-11 19:30:26 UTC; roberttreacy
Author: Christine Choirat [aut],
  Christopher Gandrud [aut],
  James Honaker [aut],
  Kosuke Imai [aut],
  Gary King [aut],
  Olivia Lau [aut],
  Robert Treacy [aut, cre],
  IQSS Harvard University [cph]
Maintainer: Robert Treacy <zelig.zee@gmail.com>
Repository: CRAN
Date/Publication: 2020-12-12 15:20:06 UTC
