import(sandwich, methods, survival, jsonlite, dplyr,
       geepack, coda, Amelia, MatchIt, maxLik, survey)

importFrom("AER", "tobit", "ivreg")
importFrom("Formula", "as.Formula")
importFrom("grDevices", "col2rgb", "heat.colors", "rgb")
importFrom("graphics", "abline", "axis", "barplot", "box", "image",
             "layout", "lines", "par", "polygon", "text")
importFrom("stats", "binomial", "complete.cases", "density",
           "glm", "lm", "lm.influence", "median", "model.frame",
             "model.matrix", "model.response", "na.omit", "quantile",
             "sd", "terms", "update", "ARMAacf", "rnorm", "pnorm")
importFrom("MASS", "glm.nb", "rnegbin", "mvrnorm", "gamma.shape")
importFrom("MCMCpack", "MCMCfactanal", "MCMClogit", "MCMCmnl", "MCMCregress",
           "MCMCoprobit", "MCMCpoisson", "MCMCprobit", "MCMCtobit")
importFrom("quantreg", "rq", "summary.rq", "bandwidth.rq")
importFrom("VGAM", "vglm")
importClassesFrom("VGAM", "vglm")
importMethodsFrom("VGAM", "coef", "fitted", "predict", "vcov")


S3method(summary, Arima)

exportPattern("^[[:alpha:]]+")
exportClasses(
     "Zelig",
     "Zelig-ls",
     "Zelig-glm",
     "Zelig-ivreg",
     "Zelig-binchoice",
     "Zelig-logit",
     "Zelig-probit",
     "Zelig-gamma",
     "Zelig-exp",
     "Zelig-negbin",
     "Zelig-normal",
     "Zelig-poisson",
     "Zelig-lognorm",
     "Zelig-tobit",
     "Zelig-gee",
     "Zelig-binchoice-gee",
     "Zelig-logit-gee",
     "Zelig-probit-gee",
     "Zelig-gamma-gee",
     "Zelig-normal-gee",
     "Zelig-poisson-gee",
     "Zelig-bayes",
     "Zelig-factor-bayes",
     "Zelig-logit-bayes",
     "Zelig-mlogit-bayes",
     "Zelig-normal-bayes",
     "Zelig-oprobit-bayes",
     "Zelig-poisson-bayes",
     "Zelig-probit-bayes",
     "Zelig-tobit-bayes",
     "Zelig-weibull",
     "Zelig-timeseries",
     "Zelig-arima",
     "Zelig-ar",
     "Zelig-ma"
)
