#' Cigarette Consumption Panel Data
#'
#' @docType data
#' @source From Christian Kleiber and Achim Zeileis (2008). Applied
#' Econometrics with R. New York: Springer-Verlag. ISBN 978-0-387-77316-2. URL
#' <https://CRAN.R-project.org/package=AER>
#' @keywords datasets
#' @md
#' @format A data set with 96 observations and 9 variables
#' @name CigarettesSW
NULL
