% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{statlevel}
\alias{statlevel}
\title{Describe Here}
\usage{
statlevel(qi, num)
}
\arguments{
\item{qi}{quantity of interest in the discrete case}

\item{num}{number of simulations}
}
\value{
a formatted quantity of interest
}
\description{
Describe Here
}
\author{
Christine Choirat
}
\keyword{internal}
