\name{grunfeld}

\alias{grunfeld}

\title{Simulation Data for model Seemingly Unrelated Regression (sur) that corresponds to method SUR of systemfit}

\description{
  Dataframe contains 20 annual observations from 1935 to
  1954 of 7 variables for two firms General Electric  and Westinghouse.
  Columns are Year; Ige and Iw = Gross investment for GE and
  W,respectively; Fge and Fw=Market value of Firm as of
  begin of the year; Cge and Cw= Capital stock measure as of begin of
  the year.  
}

\usage{data(grunfeld)}

\format{
  A table containing 7 variables ("Year", "Ige", "Fge", "Cge","Iw", "Fw","Cw")
  and 20 observations.  
}

\keyword{datasets}
