\name{swiss}

\alias{swiss}

\title{Swiss Fertility and Socioeconomic Indicators (1888) Data}

\description{
   Standardized fertility measure and socio-economic indicators for
     each of 47 French-speaking provinces of Switzerland at about 1888.
}

\usage{data(swiss)}

\format{
      A data frame with 47 observations on 6 variables, each of which
      is in percent, i.e., in [0,100].
      
       [,1]  Fertility         Ig, "common standardized fertility measure"
       [,2]  Agriculture       % of males involved in agriculture as occupation
       [,3]  Examination       % "draftees" receiving highest mark on army exami
nation
       [,4]  Education         % education beyond primary school for "draftees".
       [,5]  Catholic          % catholic (as opposed to "protestant").
       [,6]  Infant.Mortality  live births who live less than 1 year.

     All variables but 'Fert' give proportions of the population.
}

\source{


  Project "16P5", pages 549-551 in
  
  Mosteller, F. and Tukey, J. W. (1977) ``Data Analysis and
  Regression: A Second Course in Statistics''. Addison-Wesley,
  Reading Mass.

  indicating their source as "Data used by permission of Franice van
  de Walle. Office of Population Research, Princeton University,
  1976.  Unpublished data assembled under NICHD contract number No
  1-HD-O-2077."
  }

 \references{
   Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988) ``The New S
   Language''. Wadsworth & Brooks/Cole.

}


\keyword{datasets}
