% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{vcov_rq}
\alias{vcov_rq}
\title{Find vcov for quantile regression models}
\usage{
vcov_rq(obj)
}
\arguments{
\item{obj}{a \code{rq} class object.}
}
\description{
Find vcov for quantile regression models
}
