\name{macro}

\alias{macro}

\title{Macroeconomic Data}

\description{
  Selected macroeconomic indicators for Austria, Belgium, Canada,
  Denmark, Finland, France, Italy, Japan, the Netherlands, Norway,
  Sweden, the United Kingdom, the United States, and West Germany for
  the period 1966-1990.  
}

\usage{data(macro)}

\format{
  A table containing 6 variables ("country", "year", "gdp", 
  "unem", "capmob", and "trade") and 350 observations.
}

\source{ICPSR}

\references{
  King, Gary, Michael Tomz and Jason Wittenberg. ICPSR Publication
  Related Archive, 1225.
  
  King, Gary, Michael Tomz and Jason Wittenberg (2000).
  ``Making the Most of Statistical Analyses: Improving Interpretation and 
  Presentation,'' \emph{American Journal of Political Science}, vol. 44,
  pp. 341-355.
}

\keyword{datasets}




