% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{vcov_gee}
\alias{vcov_gee}
\title{Find vcov for GEE models}
\usage{
vcov_gee(obj)
}
\arguments{
\item{obj}{a \code{geeglm} class object.}
}
\description{
Find vcov for GEE models
}
