\name{newpainters}

\alias{newpainters}

\title{The Discretized Painter's Data of de Piles}

\description{
     The original painters data contain the subjective assessment, 
     on a 0 to 20 integer scale, of 54 classical painters. The
     newpainters data discretizes the subjective assessment by
     quartiles with thresholds 25\%, 50\%, 75\%. The painters were 
     assessed on four characteristics: composition, drawing, 
     colour and expression.  The data is due to the Eighteenth century 
     art critic, de Piles.

}

\usage{data(newpainters)}

\format{A table containing 5 variables ("Composition", "Drawing", "Colour", 
"Expression", and "School") and 54 observations.}

\source{

     A. J. Weekes (1986).``A Genstat Primer''. Edward Arnold.

     M. Davenport and G. Studdert-Kennedy (1972). ``The statistical
     analysis of aesthetic judgement: an exploration.'' \emph{Applied
     Statistics}, vol. 21,  pp. 324--333.

     I. T. Jolliffe (1986) ``Principal Component Analysis.'' Springer.
}

\references{

     Venables, W. N. and Ripley, B. D. (2002) ``Modern Applied
     Statistics with S,'' Fourth edition.  Springer.
}

\keyword{datasets}
